********************
flask-taxonomies-es
********************

.. image:: https://img.shields.io/travis/oarepo/flask-taxonomies-es.svg
        :target: https://travis-ci.org/oarepo/flask-taxonomies-es
        
.. image:: https://coveralls.io/repos/github/oarepo/flask-taxonomies-es/badge.svg?branch=master
        :target: https://coveralls.io/github/oarepo/flask-taxonomies-es?branch=master
        
.. image:: https://readthedocs.org/projects/flask-taxonomies-es/badge/?version=latest
        :target: https://flask-taxonomies-es.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
        
https://flask-taxonomies-es.readthedocs.io/
